Merge Android R (rvc-dev-plus-aosp-without-vendor@6692709)

Bug: 166295507
Merged-In: I25a69ac99dc29101979d772e91feb440d1a16614
Change-Id: I1da6f480b01ed3afe1fa4fb5af78044945a51540
diff --git a/res/layout-sw600dp-w960dp-h527dp-land/all_in_one.xml b/res/layout-sw600dp-w960dp-h527dp-land/all_in_one.xml
index 7f64a7b..5e31582 100644
--- a/res/layout-sw600dp-w960dp-h527dp-land/all_in_one.xml
+++ b/res/layout-sw600dp-w960dp-h527dp-land/all_in_one.xml
@@ -55,7 +55,7 @@
             android:textSize="18sp" />
     </LinearLayout>
 
-    <!-- This is a dummy view to make hiding/unhiding easier -->
+    <!-- This is a nonessential view to make hiding/unhiding easier -->
     <View
         android:id="@+id/mini_month_container"
         android:layout_below="@id/date_group"
diff --git a/src/com/android/calendar/EventInfoFragment.java b/src/com/android/calendar/EventInfoFragment.java
index b95c7c3..0aa83d0 100644
--- a/src/com/android/calendar/EventInfoFragment.java
+++ b/src/com/android/calendar/EventInfoFragment.java
@@ -217,8 +217,8 @@
 
     static {
         if (!Utils.isJellybeanOrLater()) {
-            EVENT_PROJECTION[EVENT_INDEX_CUSTOM_APP_PACKAGE] = Events._ID; // dummy value
-            EVENT_PROJECTION[EVENT_INDEX_CUSTOM_APP_URI] = Events._ID; // dummy value
+            EVENT_PROJECTION[EVENT_INDEX_CUSTOM_APP_PACKAGE] = Events._ID; // nonessential value
+            EVENT_PROJECTION[EVENT_INDEX_CUSTOM_APP_URI] = Events._ID; // nonessential value
         }
     }
 
diff --git a/src/com/android/calendar/StickyHeaderListView.java b/src/com/android/calendar/StickyHeaderListView.java
index 25955a0..981e7af 100644
--- a/src/com/android/calendar/StickyHeaderListView.java
+++ b/src/com/android/calendar/StickyHeaderListView.java
@@ -58,7 +58,7 @@
     protected HeaderIndexer mIndexer = null;
     protected HeaderHeightListener mHeaderHeightListener = null;
     protected View mStickyHeader = null;
-    protected View mDummyHeader = null; // A invisible header used when a section has no header
+    protected View mNonessentialHeader = null; // A invisible header used when a section has no header
     protected ListView mListView = null;
     protected ListView.OnScrollListener mListener = null;
 
@@ -269,11 +269,11 @@
             boolean newView = false;
             if (sectionPos != mCurrentSectionPos) {
 
                 // No header for current position , use the dummy invisible one, hide the separator
                 if (sectionPos == -1) {
                     sectionSize = 0;
                     this.removeView(mStickyHeader);
-                    mStickyHeader = mDummyHeader;
+                    mStickyHeader = mNonessentialHeader;
                     if (mSeparatorView != null) {
                         mSeparatorView.setVisibility(View.GONE);
                     }
@@ -320,14 +320,14 @@
                     }
                 } else if (stickyHeaderHeight != 0) {
                     mStickyHeader.setTranslationY(0);
-                    if (mSeparatorView != null && !mStickyHeader.equals(mDummyHeader)) {
+                    if (mSeparatorView != null && !mStickyHeader.equals(mNonessentialHeader)) {
                         mSeparatorView.setVisibility(View.VISIBLE);
                     }
                 }
                 if (newView) {
                     mStickyHeader.setVisibility(View.INVISIBLE);
                     this.addView(mStickyHeader);
-                    if (mSeparatorView != null && !mStickyHeader.equals(mDummyHeader)){
+                    if (mSeparatorView != null && !mStickyHeader.equals(mNonessentialHeader)){
                         FrameLayout.LayoutParams params =
                                 new FrameLayout.LayoutParams(LayoutParams.MATCH_PARENT,
                                         mSeparatorWidth);
@@ -382,12 +382,12 @@
             setListView(new ListView(mContext));
         }
 
-        // Create a dummy view , it will be used in case a section has no header
-        mDummyHeader = new View (mContext);
+        // Create a nonessential view , it will be used in case a section has no header
+        mNonessentialHeader = new View (mContext);
         ViewGroup.LayoutParams params = new LayoutParams(LayoutParams.MATCH_PARENT,
                 1, Gravity.TOP);
-        mDummyHeader.setLayoutParams(params);
-        mDummyHeader.setBackgroundColor(Color.TRANSPARENT);
+        mNonessentialHeader.setLayoutParams(params);
+        mNonessentialHeader.setBackgroundColor(Color.TRANSPARENT);
 
         mChildViewsCreated = true;
     }
@@ -269,11 +269,11 @@
             if (sectionPos != mCurrentSectionPos) {
 
-                // No header for current position , use the dummy invisible one, hide the separator
+                // No header for current position , use the nonessential invisible one, hide the separator
                 if (sectionPos == -1) {
                     sectionSize = 0;